RCErrorCode class
错误码
iOS 参考 RCStatusDefine.h 的枚举 RCConnectErrorCode 和 RCErrorCode
Android 参考 RongIMClient.java 的枚举 ErrorCode
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- AppBlockedOrDeleted → const int
- AppKey 被封禁或者已删除,请检查 AppKey 是否正确
- AppKeyError → const int
- AppKey 错误
- ClientNotInit → const int
- SDK 没有初始化,使用任何 SDK 接口前必须先调用 init 接口
- ForbiddenInChatRoom → const int
- 在聊天室中被禁言
- ForbiddenInGroup → const int
- 在群组中被禁言
- InvalidParameter → const int
- 非法参数,请检查调用接口传入的参数
- KickByOtherClient → const int
- 被其他端踢掉线
- NotAuthrorized → const int
- AppKey 与 Token 不匹配,需要获取新的 token 连接 IM 原因同 TokenIncorrect
- NotInChatRoom → const int
- 不在该聊天室中
- NotInGroup → const int
- 不在该群组中
- RejectedByBlackList → const int
- 已被对方加入黑名单
- RoamingServiceUnAvailable → const int
- 历史消息云存储功能未开通
- SendMsgOverfrequency → const int
- 发送消息频率过高,1秒最多允许发送5条消息
- SightMessageDurationLimitExceed → const int
- 小视频消息时长超限,最长 10s
- Success → const int
- 成功
- TokenIncorrect → const int
- token 无效,需要获取新的 token 连接 IM 一般有已下两种原因 一是token错误,请您检查客户端初始化使用的AppKey和您服务器获取token使用的AppKey是否一致; 二是token过期,是因为您在开发者后台设置了token过期时间,您需要请求您的服务器重新获取token并再次用新的token建立连接。
- UserBlocked → const int
- 用户被封禁,请检查 Token 是否正确以及对应的 UserId 是否被封禁